@@ -31,9 +31,6 @@
 
 using namespace std;
 
-std::map<Tree, std::pair<int, std::string>> boxppShared::fExpTable;
-int boxppShared::fExpCounter = 0;
-
 const char* prim0name(CTree *(*ptr)())
 {
     return "prim0???";
@@ -382,12 +379,12 @@ ostream& boxpp::print(ostream& fout) const
 }
 
 #define INSERT_ID(exp)                             \
-    if (fExpTable.find(fBox) == fExpTable.end()) { \
+    if (gGlobal->gExpTable.find(fBox) == gGlobal->gExpTable.end()) { \
         stringstream s;                            \
         (exp);                                                     \
-        fExpTable[fBox] = std::make_pair(fExpCounter++, s.str());  \
+        gGlobal->gExpTable[fBox] = make_pair(gGlobal->gExpCounter++, s.str());  \
     }                                              \
-    fout << "ID_" << fExpTable[fBox].first;        \
+    fout << "ID_" << gGlobal->gExpTable[fBox].first;        \
 
 ostream& boxppShared::print(ostream& fout) const
 {
@@ -441,7 +438,7 @@ ostream& boxppShared::print(ostream& fout) const
         INSERT_ID(s << boxppShared(body) << " with { " << envpp(ldef) << " }");
     // Foreign elements
     } else if (isBoxFFun(fBox, ff)) {
-        if (fExpTable.find(fBox) == fExpTable.end()) {
+        if (gGlobal->gExpTable.find(fBox) == gGlobal->gExpTable.end()) {
             stringstream s;
                 
             s << "ffunction(" << type2str(ffrestype(ff));
@@ -459,10 +456,10 @@ ostream& boxppShared::print(ostream& fout) const
             s << ')';
             s << ',' << ffincfile(ff) << ',' << fflibfile(ff) << ')';
             
-            fExpTable[fBox] = std::make_pair(fExpCounter++, s.str());
+            gGlobal->gExpTable[fBox] = make_pair(gGlobal->gExpCounter++, s.str());
         }
-        // fExpCounter used a ID
-        fout << "ID_" << fExpTable[fBox].first;
+        // gGlobal->gExpCounter used a ID
+        fout << "ID_" << gGlobal->gExpTable[fBox].first;
     } else if (isBoxFConst(fBox, type, name, file)) {
         INSERT_ID(s << "fconstant(" << type2str(tree2int(type)) << ' ' << tree2str(name) << ", " << tree2str(file) << ')');
     } else if (isBoxFVar(fBox, type, name, file)) {
@@ -522,7 +519,7 @@ ostream& boxppShared::print(ostream& fout) const
     else if (isNil(fBox)) {
         fout << "()";
     } else if (isList(fBox)) {
-        if (fExpTable.find(fBox) == fExpTable.end()) {
+        if (gGlobal->gExpTable.find(fBox) == gGlobal->gExpTable.end()) {
             stringstream s;
             Tree l   = fBox;
             char sep = '(';
@@ -534,12 +531,12 @@ ostream& boxppShared::print(ostream& fout) const
             } while (isList(l));
             
             s << ')';
-            fExpTable[fBox] = std::make_pair(fExpCounter++, s.str());
+            gGlobal->gExpTable[fBox] = make_pair(gGlobal->gExpCounter++, s.str());
         }
-        // fExpCounter used a ID
-        fout << "ID_" << fExpTable[fBox].first;
+        // gGlobal->gExpCounter used a ID
+        fout << "ID_" << gGlobal->gExpTable[fBox].first;
     } else if (isBoxWaveform(fBox)) {
-        if (fExpTable.find(fBox) == fExpTable.end()) {
+        if (gGlobal->gExpTable.find(fBox) == gGlobal->gExpTable.end()) {
             stringstream s;
             s << "waveform";
             char sep = '{';
@@ -548,10 +545,10 @@ ostream& boxppShared::print(ostream& fout) const
                 sep = ',';
             }
             s << '}';
-            fExpTable[fBox] = std::make_pair(fExpCounter++, s.str());
+            gGlobal->gExpTable[fBox] = make_pair(gGlobal->gExpCounter++, s.str());
         }
-        // fExpCounter used a ID
-        fout << "ID_" << fExpTable[fBox].first;
+        // gGlobal->gExpCounter used a ID
+        fout << "ID_" << gGlobal->gExpTable[fBox].first;
     } else if (isBoxEnvironment(fBox)) {
         fout << "environment";
     } else if (isClosure(fBox, abstr, genv, vis, lenv)) {
@@ -615,7 +612,7 @@ ostream& boxppShared::print(ostream& fout) const
 
 void boxppShared::printIDs(ostream& fout)
 {
-    for (const auto& it : fExpTable) {
+    for (const auto& it : gGlobal->gExpTable) {
         fout << "ID_" << it.second.first << " = " << it.second.second << ';' << endl;
     }
 }
